# Aleatoryous 3

This is the 3rth Generation of aleatory objects, built by Diego
Ramirez.

## Introduction

The Aleatoryous package allows you to build:

- Aleatory Syntax objects
  - Dice: aleatory.dice
  - Coin: aleatory.coin
  - Roulette: aleatory.roulette

By using the [Python](http://python.org) library [random](http://docs.python.org/3.8/library/random), Aleatoryous object can build many solutions
for problems where aleatory numbers or specific output are needed.

This package is built to be used with Python versions 3.5 to 3.9.

To enjoy the Aleatoryous materials, you must download the package from the [PyPi](http://pypi.org/project/aleat3#files)
and install it with pip by one of this ways:

```
pip install aleat3_[version]_[platform].whl

pip install aleat3_[version]_[platform].tar.gz
```

Also, you can install it with Pip from Internet without downloading:

```
pip install aleat3==[version]

pip install --upgrade aleat3

pip install aleat3
```

## To view more

Check out more docs here:

- [General documentation](http://DiddiLeija.github.io/aleat3/DOCUMENTATION.md)
  - Get some useful info about the package, issues, etc.
- [Contributing page](http://DiddiLeija.github.io/aleat3/CONTRIBUTE.md)
  - Learn about how to contribute to aleat3.
- [Some aleat3 examples](http://DiddiLeija.github.io/aleat3/SOLUTIONS.md)
